==> ph-schematron-api-6.2.8-sources.jar: com/helger/schematron/svrl/jaxb/ObjectFactory.java <==

package com.helger.schematron.svrl.jaxb;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;
import com.helger.commons.annotation.CodingStyleguideUnaware;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the com.helger.schematron.svrl.jaxb package. 
 * &lt;p&gt;An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.&lt;p&gt;This class was annotated by ph-jaxb22-plugin -Xph-annotate&lt;/p&gt;
 * 
 * 
 */
@XmlRegistry
@CodingStyleguideUnaware
public class ObjectFactory {

    public final static QName _SchematronOutput_QNAME = new QName("http://purl.oclc.org/dsdl/svrl", "schematron-output");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: com.helger.schematron.svrl.jaxb
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link SchematronOutputType }
     * 
     * @return
     *     The created SchematronOutputType object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public SchematronOutputType createSchematronOutputType() {
        return new SchematronOutputType();
    }

    /**
     * Create an instance of {@link NsPrefixInAttributeValues }
     * 
     * @return
     *     The created NsPrefixInAttributeValues object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public NsPrefixInAttributeValues createNsPrefixInAttributeValues() {
        return new NsPrefixInAttributeValues();
    }

    /**
     * Create an instance of {@link ActivePattern }
     * 
     * @return
     *     The created ActivePattern object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public ActivePattern createActivePattern() {
        return new ActivePattern();
    }

    /**
     * Create an instance of {@link Text }
     * 
     * @return
     *     The created Text object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public Text createText() {
        return new Text();
    }

    /**
     * Create an instance of {@link RichText }
     * 
     * @return
     *     The created RichText object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public RichText createRichText() {
        return new RichText();
    }

    /**
     * Create an instance of {@link Dir }
     * 
     * @return
     *     The created Dir object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public Dir createDir() {
        return new Dir();
    }

    /**
     * Create an instance of {@link Span }
     * 
     * @return
     *     The created Span object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public Span createSpan() {
        return new Span();
    }

    /**
     * Create an instance of {@link Emph }
     * 
     * @return
     *     The created Emph object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public Emph createEmph() {
        return new Emph();
    }

    /**
     * Create an instance of {@link FiredRule }
     * 
     * @return
     *     The created FiredRule object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public FiredRule createFiredRule() {
        return new FiredRule();
    }

    /**
     * Create an instance of {@link DiagnosticReference }
     * 
     * @return
     *     The created DiagnosticReference object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public DiagnosticReference createDiagnosticReference() {
        return new DiagnosticReference();
    }

    /**
     * Create an instance of {@link FailedAssert }
     * 
     * @return
     *     The created FailedAssert object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public FailedAssert createFailedAssert() {
        return new FailedAssert();
    }

    /**
     * Create an instance of {@link PropertyReference }
     * 
     * @return
     *     The created PropertyReference object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public PropertyReference createPropertyReference() {
        return new PropertyReference();
    }

    /**
     * Create an instance of {@link SuccessfulReport }
     * 
     * @return
     *     The created SuccessfulReport object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public SuccessfulReport createSuccessfulReport() {
        return new SuccessfulReport();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SchematronOutputType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link SchematronOutputType }{@code >} The created JAXBElement and never &lt;code&gt;null&lt;/code&gt;.
     */
    @XmlElementDecl(namespace = "http://purl.oclc.org/dsdl/svrl", name = "schematron-output")
    @Nonnull
    public JAXBElement<SchematronOutputType> createSchematronOutput(
        @Nullable
        final SchematronOutputType value) {
        return new JAXBElement<SchematronOutputType>(_SchematronOutput_QNAME, SchematronOutputType.class, null, value);
    }

}

==> ph-schematron-api-7.1.2-sources.jar: com/helger/schematron/svrl/jaxb/ObjectFactory.java <==

package com.helger.schematron.svrl.jaxb;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.namespace.QName;
import com.helger.commons.annotation.CodingStyleguideUnaware;
import jakarta.xml.bind.JAXBElement;
import jakarta.xml.bind.annotation.XmlElementDecl;
import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the com.helger.schematron.svrl.jaxb package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.<p>This class was annotated by ph-jaxb-plugin -Xph-annotate</p>
 * 
 * 
 */
@XmlRegistry
@CodingStyleguideUnaware
public class ObjectFactory {

    public final static QName _SchematronOutput_QNAME = new QName("http://purl.oclc.org/dsdl/svrl", "schematron-output");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: com.helger.schematron.svrl.jaxb
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link SchematronOutputType }
     * 
     * @return
     *     the new instance of {@link SchematronOutputType } The created SchematronOutputType object and never <code>null</code>.
     */
    @Nonnull
    public SchematronOutputType createSchematronOutputType() {
        return new SchematronOutputType();
    }

    /**
     * Create an instance of {@link NsPrefixInAttributeValues }
     * 
     * @return
     *     the new instance of {@link NsPrefixInAttributeValues } The created NsPrefixInAttributeValues object and never <code>null</code>.
     */
    @Nonnull
    public NsPrefixInAttributeValues createNsPrefixInAttributeValues() {
        return new NsPrefixInAttributeValues();
    }

    /**
     * Create an instance of {@link ActivePattern }
     * 
     * @return
     *     the new instance of {@link ActivePattern } The created ActivePattern object and never <code>null</code>.
     */
    @Nonnull
    public ActivePattern createActivePattern() {
        return new ActivePattern();
    }

    /**
     * Create an instance of {@link Text }
     * 
     * @return
     *     the new instance of {@link Text } The created Text object and never <code>null</code>.
     */
    @Nonnull
    public Text createText() {
        return new Text();
    }

    /**
     * Create an instance of {@link RichText }
     * 
     * @return
     *     the new instance of {@link RichText } The created RichText object and never <code>null</code>.
     */
    @Nonnull
    public RichText createRichText() {
        return new RichText();
    }

    /**
     * Create an instance of {@link Dir }
     * 
     * @return
     *     the new instance of {@link Dir } The created Dir object and never <code>null</code>.
     */
    @Nonnull
    public Dir createDir() {
        return new Dir();
    }

    /**
     * Create an instance of {@link Span }
     * 
     * @return
     *     the new instance of {@link Span } The created Span object and never <code>null</code>.
     */
    @Nonnull
    public Span createSpan() {
        return new Span();
    }

    /**
     * Create an instance of {@link Emph }
     * 
     * @return
     *     the new instance of {@link Emph } The created Emph object and never <code>null</code>.
     */
    @Nonnull
    public Emph createEmph() {
        return new Emph();
    }

    /**
     * Create an instance of {@link FiredRule }
     * 
     * @return
     *     the new instance of {@link FiredRule } The created FiredRule object and never <code>null</code>.
     */
    @Nonnull
    public FiredRule createFiredRule() {
        return new FiredRule();
    }

    /**
     * Create an instance of {@link DiagnosticReference }
     * 
     * @return
     *     the new instance of {@link DiagnosticReference } The created DiagnosticReference object and never <code>null</code>.
     */
    @Nonnull
    public DiagnosticReference createDiagnosticReference() {
        return new DiagnosticReference();
    }

    /**
     * Create an instance of {@link FailedAssert }
     * 
     * @return
     *     the new instance of {@link FailedAssert } The created FailedAssert object and never <code>null</code>.
     */
    @Nonnull
    public FailedAssert createFailedAssert() {
        return new FailedAssert();
    }

    /**
     * Create an instance of {@link PropertyReference }
     * 
     * @return
     *     the new instance of {@link PropertyReference } The created PropertyReference object and never <code>null</code>.
     */
    @Nonnull
    public PropertyReference createPropertyReference() {
        return new PropertyReference();
    }

    /**
     * Create an instance of {@link SuccessfulReport }
     * 
     * @return
     *     the new instance of {@link SuccessfulReport } The created SuccessfulReport object and never <code>null</code>.
     */
    @Nonnull
    public SuccessfulReport createSuccessfulReport() {
        return new SuccessfulReport();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SchematronOutputType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link SchematronOutputType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://purl.oclc.org/dsdl/svrl", name = "schematron-output")
    @Nonnull
    public JAXBElement<SchematronOutputType> createSchematronOutput(
        @Nullable
        final SchematronOutputType value) {
        return new JAXBElement<>(_SchematronOutput_QNAME, SchematronOutputType.class, null, value);
    }

}
